pub fn validate_bundle_file(path: &Path) -> Result<ValidatedBundle>Expand description
Load, validate, and compose a policy bundle from disk.
pub fn validate_bundle_file(path: &Path) -> Result<ValidatedBundle>Load, validate, and compose a policy bundle from disk.