pub fn format_candidate_status(
name: &str,
namespace: &str,
candidate: &Value,
plan_name: Option<&str>,
plan: Option<&Value>,
) -> StringExpand description
Render pgroles candidate status for one candidate and its plan.
plan is None when the candidate has not been planned yet — the caller
reports that as a hard error for diff, but status is exactly the command
that should be able to explain an unplanned candidate.